TableComponent

Enum TableComponent 

pub enum TableComponent {
Show 19 variants LeftBorder, RightBorder, TopBorder, BottomBorder, LeftHeaderIntersection, HeaderLines, MiddleHeaderIntersections, RightHeaderIntersection, VerticalLines, HorizontalLines, MiddleIntersections, LeftBorderIntersections, RightBorderIntersections, TopBorderIntersections, BottomBorderIntersections, TopLeftCorner, TopRightCorner, BottomLeftCorner, BottomRightCorner,
}
All configurable table components. A character can be assigned to each component via Table::set_style. This is then used to draw character of the respective component to the commandline.

I hope that most component names are self-explanatory. Just in case: BorderIntersections are Intersections, where rows/columns lines meet outer borders. E.g.:

       ---------
       v       |
+---+---+---+  |
| a | b | c |  |
+===+===+===+<-|
|   |   |   |  |
+---+---+---+<-- These "+" chars are Borderintersections.
|   |   |   |    The inner "+" chars are MiddleIntersections
+---+---+---+

Variants



LeftBorder



RightBorder



TopBorder



BottomBorder



LeftHeaderIntersection



HeaderLines



MiddleHeaderIntersections



RightHeaderIntersection



VerticalLines



HorizontalLines



MiddleIntersections



LeftBorderIntersections



RightBorderIntersections



TopBorderIntersections



BottomBorderIntersections



TopLeftCorner



TopRightCorner



BottomLeftCorner



BottomRightCorner

Implementations