ContentLineStyle

Struct ContentLineStyle 

pub struct ContentLineStyle {
    pub left: Option<char>,
    pub junction: Option<char>,
    pub right: Option<char>,
}
A styling rule for the lines of a table that contain content.

This could be the header lines or the content lines of normal rows.

A styling rule consists of three optional parts:

│ a         ┆ b         │
^           ^           ^
left        junction    right

left/right are the border delimiters and junction is the vertical delimiter that’s drawn between columns.

Fields

left: Option<char>junction: Option<char>right: Option<char>

Implementations

Source

impl ContentLineStyle

pub const fn new(left: char, junction: char, right: char) -> Self

Create a ContentLineStyle with all three parts set.

pub const fn none() -> Self

Create a line without any parts set.

pub const fn left(self, character: char) -> Self

Set the left border character.

pub const fn junction(self, character: char) -> Self

Set the junction character.

pub const fn right(self, character: char) -> Self

Set the right border character.