pub struct LineStyle {
pub left: Option<char>,
pub fill: Option<char>,
pub junction: Option<char>,
pub right: Option<char>,
}Expand description
A styling rule for a type of horizontal line of a table.
This could be, for example, the top border or the lines between rows.
A styling rule consists of four optional parts:
├╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌┤
^ ^ ^ ^
left fill junction rightleft/right are the border delimiters, fill is the horizontal delimiter between rows and
junction is drawn where vertical and horizontal lines cross in the middle
Styles that’re wholly None won’t be drawn.
Fields
left: Option<char>fill: Option<char>junction: Option<char>right: Option<char>Implementations