pub struct TableStyle {
pub top_border: LineStyle,
pub header_lines: ContentLineStyle,
pub header_separator: LineStyle,
pub content_lines: ContentLineStyle,
pub row_separator: LineStyle,
pub bottom_border: LineStyle,
}Expand description
The full description of a table’s look, built from four horizontal LineStyles and two ContentLineStyles:
┌─────────┬─────────┐ <- top_border
│ Hello ┆ there │ <- header_lines
╞═════════╪═════════╡ <- header_separator
│ a ┆ b │ <- content_lines
├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┤ <- row_separator
│ c ┆ d │
└─────────┴─────────┘ <- bottom_borderAll functions for building a style are const, so custom styles can be declared as
constants, just like the ones in the presets module:
use comfy_table::{ContentLineStyle, LineStyle, Table, TableStyle};
const MY_STYLE: TableStyle = TableStyle::new()
.top_border(LineStyle::new('┌', '─', '┬', '┐'))
.header_lines(ContentLineStyle::new('│', '┆', '│'))
.header_separator(LineStyle::new('╞', '═', '╪', '╡'))
.content_lines(ContentLineStyle::new('│', '┆', '│'))
.bottom_border(LineStyle::new('└', '─', '┴', '┘'));
let mut table = Table::new();
table.load_style(MY_STYLE);Fields
top_border: LineStyleheader_lines: ContentLineStyleheader_separator: LineStylecontent_lines: ContentLineStylerow_separator: LineStylebottom_border: LineStyleImplementations
Sourceimpl TableStyle
impl TableStyle
Sourcepub const fn top_border(self, line: LineStyle) -> Self
pub const fn top_border(self, line: LineStyle) -> Self
Set the top border of the table.
Sourcepub const fn header_lines(self, line: ContentLineStyle) -> Self
pub const fn header_lines(self, line: ContentLineStyle) -> Self
Set the style of the lines that contain the header’s content.
Sourcepub const fn header_separator(self, line: LineStyle) -> Self
pub const fn header_separator(self, line: LineStyle) -> Self
Set the line that’s drawn between the header and the first row.
Sourcepub const fn content_lines(self, line: ContentLineStyle) -> Self
pub const fn content_lines(self, line: ContentLineStyle) -> Self
Set the style of the lines that contain the rows’ content.
Sourcepub const fn row_separator(self, line: LineStyle) -> Self
pub const fn row_separator(self, line: LineStyle) -> Self
Set the line that’s drawn between rows.
Sourcepub const fn bottom_border(self, line: LineStyle) -> Self
pub const fn bottom_border(self, line: LineStyle) -> Self
Set the bottom border of the table.
Sourcepub const fn with_rounded_corners(self) -> Self
pub const fn with_rounded_corners(self) -> Self
Convert the outer corners to round corners.
╭───────┬───────╮
│ Hello │ there │
╞═══════╪═══════╡
│ a ┆ b │
├╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┤
│ c ┆ d │
╰───────┴───────╯Sourcepub const fn with_solid_inner_borders(self) -> Self
pub const fn with_solid_inner_borders(self) -> Self
Convert the inner borders to solid lines.
┌───────┬───────┐
│ Hello │ there │
╞═══════╪═══════╡
│ a │ b │
├───────┼───────┤
│ c │ d │
└───────┴───────┘Trait Implementations
Sourceimpl Clone for TableStyle
impl Clone for TableStyle
Sourcefn clone(&self) -> TableStyle
fn clone(&self) -> TableStyle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TableStyle
Sourceimpl Debug for TableStyle
impl Debug for TableStyle
Sourceimpl Default for TableStyle
impl Default for TableStyle
Sourcefn default() -> TableStyle
fn default() -> TableStyle
Returns the “default value” for a type. Read more
impl Eq for TableStyle
Sourceimpl PartialEq for TableStyle
impl PartialEq for TableStyle
impl StructuralPartialEq for TableStyle