pub struct ContentLineStyle {
pub left: Option<char>,
pub junction: Option<char>,
pub right: Option<char>,
}Expand description
A styling rule for the lines of a table that contain content.
This could be the header lines or the content lines of normal rows.
A styling rule consists of three optional parts:
│ a ┆ b │
^ ^ ^
left junction rightleft/right are the border delimiters and junction is the vertical delimiter that’s
drawn between columns.
Fields
left: Option<char>junction: Option<char>right: Option<char>Implementations
Sourceimpl ContentLineStyle
impl ContentLineStyle