LineStyle

Struct LineStyle 

pub struct LineStyle {
    pub left: Option<char>,
    pub fill: Option<char>,
    pub junction: Option<char>,
    pub right: Option<char>,
}
A styling rule for a type of horizontal line of a table.

This could be, for example, the top border or the lines between rows.

A styling rule consists of four optional parts:

├╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌┤
^     ^     ^           ^
left  fill  junction    right

left/right are the border delimiters, fill is the horizontal delimiter between rows and junction is drawn where vertical and horizontal lines cross in the middle

Styles that’re wholly None won’t be drawn.

Fields

left: Option<char>fill: Option<char>junction: Option<char>right: Option<char>

Implementations

Source

impl LineStyle

pub const fn new(left: char, fill: char, junction: char, right: char) -> Self

Create a LineStyle with all four parts set.

pub const fn none() -> Self

Create a line without any parts set.

pub const fn left(self, character: char) -> Self

Set the left border character.

pub const fn fill(self, character: char) -> Self

Set the fill character.

pub const fn junction(self, character: char) -> Self

Set the junction character.

pub const fn right(self, character: char) -> Self

Set the right border character.